@@ -1,5 +1,6 @@
 import struct
 
+from ptpip.constants.packet_type import PacketType
 from ptpip.constants.data_object_transfer_mode import DataObjectTransferMode
 
 from ptpip.data_object.data_object import DataObject
@@ -15,7 +16,7 @@ class InitFail(Packet):
         dataObjectTransferMode: DataObjectTransferMode = None
     ):
         super(InitFail, self).__init__(
-            5,
+            PacketType.InitFail,
             data = data,
             transactionId = transactionId,
             dataObject = dataObject,
@@ -24,4 +25,4 @@ class InitFail(Packet):
 
     def __str__(self):
         return 'InitFail: ' + "\n" \
-            + "\t" + 'cmdtype: ' + str(self.cmdtype) + "\n"
+            + "\t" + 'type: ' + str(self.type) + "\n"
